@@ -1,27 +1,27 @@
 #' Prepare the raster brick containing the precipitation data
 #' 
 #' This functions turns the WorldClim data downloaded using the function
-#' \code{\link{getprecip}} into a \var{RasterBrick} of same resolution and
+#' [getprecip] into a *RasterBrick* of same resolution and
 #' extent as the structural raster. This function is designed to be used with
-#' \code{\link{isomultiscape}}.
+#' [isomultiscape].
 #' 
-#' @param path A \var{string} indicating the path where the WorldClim data have
+#' @param path A *string* indicating the path where the WorldClim data have
 #'   been downloaded. If the path is null (the default) the function will assume
 #'   that the folder containing the precipitation data is in the current 
 #'   directory
-#' @param raster A \var{raster} containing the structural raster
-#' @param verbose A \var{logical} indicating whether information about the 
+#' @param raster A *raster* containing the structural raster
+#' @param verbose A *logical* indicating whether information about the 
 #'   progress of the procedure should be displayed or not while the function is 
-#'   running. By default verbose is \var{TRUE} if users use an interactive R 
-#'   session, and \var{FALSE} otherwise.
+#'   running. By default verbose is `TRUE` if users use an interactive R 
+#'   session, and `FALSE` otherwise.
 #'   
 #' @seealso
 #' 
-#' \code{\link{getprecip}} to download the relevant precipitation data
+#' [getprecip] to download the relevant precipitation data
 #' 
-#' \code{\link{PrecipBrickDE}} for the stored precipitation data for Germany
+#' [PrecipBrickDE] for the stored precipitation data for Germany
 #' 
-#' \code{\link{prepelev}} to prepare an elevation raster
+#' [prepelev] to prepare an elevation raster
 #' 
 #' @examples
 #' 
@@ -32,17 +32,21 @@
 #' #GNIPDataDEagg <- prepsources(data = GNIPDataDE)
 #' #
 #' #GermanFit <- isofit(data = GNIPDataDEagg,
-#' #                    mean_model_fix = list(elev = TRUE, lat.abs = TRUE))
+#' #                     mean_model_fix = list(elev = TRUE, lat.abs = TRUE))
 #' #
+#' ### We prepare the structural raster:
 #' #StrRaster <- prepraster(raster = ElevRasterDE,
 #' #                        isofit = GermanFit,
 #' #                        aggregation_factor = 0)
 #' #
-#' #getprecip(path = "~/Desktop/")
+#' ### We download the precipitation data:
+#' #getprecip(path = "~/Downloads/")
 #' #
-#' #PrecipitationBrick <- prepcipitate(path = "~/Desktop/",
-#' #                                   raster = StrRaster
-#' #                                   )
+#' ### We prepare the raster brick with all the precipitation data:
+#' #PrecipitationBrick <- prepcipitate(path = "~/Downloads/",
+#' #                                   raster = StrRaster)
+#' #
+#' ### We plot the precipitation data:
 #' #levelplot(PrecipitationBrick)
 #'
 #' @export
@@ -53,9 +57,9 @@ prepcipitate <- function(path = NULL,
   
   ## Prepare path
   if (is.null(path)) {
-    path <- paste0(getwd(), "/wc2.0_30s_prec")
+    path <- paste0(getwd(), "/wc2.1_30s_prec")
   } else {
-    path <- paste0(path, "/wc2.0_30s_prec")
+    path <- paste0(path, "/wc2.1_30s_prec")
   }
   
   path <- normalizePath(path, mustWork = FALSE)
@@ -69,13 +73,13 @@ prepcipitate <- function(path = NULL,
   }
   
   ## Checks if the tif files are the good ones
-  if (!all(paste0("wc2.0_30s_prec_", formatC(1:12, digits = 0, width = 2, format = "f", flag = 0), ".tif") %in% list_tif)) {
-    stop("The '.tif' files do not have expected names: 'wc2.0_30s_prec_01.tif', 'wc2.0_30s_prec_02.tif', ...")
+  if (!all(paste0("wc2.1_30s_prec_", formatC(1:12, digits = 0, width = 2, format = "f", flag = 0), ".tif") %in% list_tif)) {
+    stop("The '.tif' files do not have expected names: 'wc2.1_30s_prec_01.tif', 'wc2.1_30s_prec_02.tif', ...")
   }
   
   ## Small function to get the name of a given file
   getfilename <- function(month) {
-    paste0(path, "/wc2.0_30s_prec_", formatC(month, digits = 0, width = 2, format = "f", flag = 0), ".tif")
+    paste0(path, "/wc2.1_30s_prec_", formatC(month, digits = 0, width = 2, format = "f", flag = 0), ".tif")
   }
   
   ## Import and resize rasters one by one
@@ -84,6 +88,13 @@ prepcipitate <- function(path = NULL,
       print(paste("Preparing precipitation raster for month", month, "..."), quote = FALSE)
     }
     tmp.raster <- raster::raster(getfilename(month))
+    ## crop before resampling to save a lot of time
+    tmp.raster <- .crop_withmargin(tmp.raster,
+                                   xmin = raster::xmin(raster),
+                                   xmax = raster::xmax(raster),
+                                   ymin = raster::ymin(raster),
+                                   ymax = raster::ymax(raster),
+                                   margin_pct = 10) # 10% hardcoded, probably fine for most case
     assign(paste0("month_", month), raster::resample(x = tmp.raster, y = raster))
     rm(tmp.raster)
   }
